#
# spec file for package discover
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang
Name:           discover
Version:        5.12.8
Release:        lp150.7.1
Summary:        KDE Software Installer
License:        GPL-2.0 and GPL-3.0 and GPL-3.0+
Group:          System/GUI/KDE
Url:            https://quickgit.kde.org/?p=discover.git
Source:         https://download.kde.org/stable/plasma/%{version}/discover-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch1:         0001-Warning-for-FlatHub.patch
%if 0%{?suse_version} < 1330
# It does not build with the default compiler (GCC 4.8) on Leap 42.x
%if 0%{?sle_version} < 120300
BuildRequires:  gcc6-c++
%else
BuildRequires:  gcc7-c++
%endif
%endif
BuildRequires:  PackageKit-Qt5-devel
BuildRequires:  cmake >= 2.8.12
BuildRequires:  extra-cmake-modules
BuildRequires:  flatpak-devel
BuildRequires:  kf5-filesystem
BuildRequires:  kirigami2-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(AppStreamQt) >= 0.11.1
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Attica)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qca-qt5)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
Requires:       AppStream
Requires:       PackageKit
Requires:       flatpak
Requires:       kirigami2
Requires:       libqt5-qtquickcontrols2
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120300
Requires:       appstream-provider
%else
Requires:       libzypp-plugin-appdata
%endif
%if %{with lang}
Recommends:     %{name}-lang
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Disover is the KDE software installer, implemented as an app store like application.

%package plasmoid
Summary:        Update notification plasmoid for KDE Software Manager
Group:          System/GUI/KDE
Conflicts:      plasma5-pk-updates
Requires:       %{name} = %{version}

%description plasmoid
This is the systray plasmoid to notify the user that updates are available

%lang_package

%prep
%setup -q
%autopatch -p1

%build
  %if 0%{?suse_version} < 1330
    # It does not build with the default compiler (GCC 4.8) on Leap 42.x
  %if 0%{?sle_version} < 120300
    export CC=gcc-6
    export CXX=g++-6
  %else
    export CC=gcc-7
    export CXX=g++-7
  %endif
  %endif
  %cmake_kf5 -d build -- -DBUILD_TESTING=ON
  %make_jobs

%install
  %kf5_makeinstall -C build
  %suse_update_desktop_file -r org.kde.discover Qt KDE System PackageManager

%if %{with lang}
  %find_lang libdiscover %{name}.lang
#  %find_lang plasma-discover-exporter %{name}.lang
  %find_lang plasma-discover-notifier %{name}.lang
  %find_lang plasma-discover %{name}.lang

  %find_lang plasma_applet_org.kde.discovernotifier plasma.lang
%else
  touch plasma.lang
%endif

%files
%defattr(-,root,root)
%doc COPYING COPYING.GFDL COPYING.LIB
%{_kf5_bindir}/plasma-discover
%{_kf5_libdir}/plasma-discover/
%{_kf5_plugindir}/discover/
%{_kf5_qmldir}/
%{_kf5_applicationsdir}/org.kde.discover.desktop
%{_kf5_applicationsdir}/org.kde.discover-flatpak.desktop
%{_kf5_applicationsdir}/org.kde.discover.urlhandler.desktop
%{_kf5_iconsdir}/hicolor/*/apps/plasmadiscover.*
%{_kf5_notifydir}/discoverabstractnotifier.notifyrc
%{_kf5_kxmlguidir}/plasmadiscover/
%{_kf5_sharedir}/libdiscover/
%{_kf5_appstreamdir}/
%{_kf5_sharedir}/discover/
%{_libdir}/libexec/kf5/discover/
%config %{_kf5_configdir}/discover_ktexteditor_codesnippets_core.knsrc

%if %{with lang}
%files lang -f %{name}.lang
%defattr(-,root,root)
%endif

%files plasmoid -f plasma.lang
%defattr(-,root,root)
%doc COPYING COPYING.GFDL COPYING.LIB
%dir %{_kf5_sharedir}/plasma
%dir %{_kf5_sharedir}/plasma/plasmoids
%{_kf5_sharedir}/plasma/plasmoids/org.kde.discovernotifier/
%{_kf5_servicesdir}/plasma-applet-org.kde.discovernotifier.desktop
%{_kf5_plugindir}/discover-notifier/

%changelog
* Tue Mar  5 2019 fabian@ritter-vogt.de
- Update to 5.12.8
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.8.php
- No code changes since 5.12.7
* Tue Sep 25 2018 fabian@ritter-vogt.de
- Update to 5.12.7
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.7.php
- Changes since 5.12.6:
  * Fix showing update notification (kde#396426,kde#390322)
  * Don't try to trigger an empty transaction (kde#397759)
  * PK: wait until we have fetched the packages that dont' come from appstream (kde#397192)
  * Fix navigation after search (kde#391931)
  * Remove wrong assert
  * KNS: Fix leak of resource ratings
  * Prevent crash (kde#396564)
  * Readability
  * Fix CMakeLists.txt to work with older versions of CMake
  * Fix warning
  * Silence false positive warning on --mode
  * Proper status when removing snaps (kde#396351)
  * Properly check for pkqt
  * Use consistent spacing in the missing backends footer
  * PK: Make sure we resolve the transaction application if it fails (kde#395994)
  * KNS: don't start searches before initializing (kde#395966)
  * Report a progressing change when we finish to set up and there's nothing pending
  * Recheck fetching after we remove a backend
  * flatpak: don't crash if we get null updates (kde#394713)
* Wed Aug 22 2018 fabian@ritter-vogt.de
- Update to 5.12.6 (boo#1105686)
* Wed Jun 27 2018 fabian@ritter-vogt.de
- Update to 5.12.6
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.6.php
- Too many changes to list here
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * Improve display of Progress element (kde#393323)
  * More elegant syntax for qrc files in cmake
  * Make sure we update the checkability of all delegates when one changes
  * PK: Improve information on resources that extend others
  * Report 0%% update progress when not progressing
  * Infer cancellability of the StandardBackendUpdater (kde#390319)
  * Forward action enabled state into the button
  * Don't change the resources while updating (kde#391262)
  * Remove unused variable
  * Fix typo
  * Fix notifier button placement
  * Fix warning on Qt 5.11
  * Remove wrongly commented code
  * Report when root categories change
  * Readability
  * Properly concatenate strings
  * Fix crash when installing flatpak files
  * Remove unneeded dependency
  * Don't crash when cancelling flatpak jobs (kde#391941)
  * Remove unused imports
  * --debug
  * Make sure we don't crash automatically (kde#392082)
  * Fix sorting when the actual comparison matches
  * Fix warning in Qt 5.11
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * Simplify the tasks view (kde#391760)
  * Remove unneeded includes
  * Fix dbus path
  * Include a test for cancelling flatpak installations
  * Improve status of FlatpakTransaction
  * Remove pointless i18n call
  * KNS: Only indicate that it's fetching if already fetching reviews
  * Include a test that makes sure we can list origins
  * Solve some inconsistencies found when testing flatpak
  * Introduce a flatpak test
  * No need to pass the extra arguments on the Update Action (kde#391801)
  * Add Qt5::Xml
  * Simplify KNSTransaction creation (kde#390236)
  * Fix test
  * Add a test to make sure we don't add resources with the wrong URL
  * kns: Fix logic for adding screenshots (kde#391190)
  * Add debug information when the searched URI is wrong
* Fri Mar 23 2018 fabian@ritter-vogt.de
- Add patch to show an informative warning when adding FlatHub:
  * 0001-Warning-for-FlatHub.patch
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Too many changes to list here
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * Fix checking if the package is already on the ResProxyModel
  * Add multimedia sub-categories
  * Put all systemwide add-ons in Plasma Addons category (kde#390594)
  * Sort by sortable rating
  * Make it possible to debug sorting
  * Make sure sortableRating is initialised
  * Don't let the user write the first review for apps they haven't installed
  * Fix warning
  * Only instantiate the ProgressView sheet when it's to be displayed
  * Fix placement of the BusyIndicator over loading screenshots (kde#390391)
  * Update copyright year (kde#390358)
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Update copyright year (kde#390358)
  * Notify about the backend (kde#390339)
  * Don't notify when the number of updates becomes smaller (kde#390322)
  * Remove commented out code
  * Forgot to add file
  * Fix freeze when showing the ApplicationPage (kde#390123)
  * Only report changes when they actually happen
  * Fix binding loop when showing the update description
  * Disable Review button for resources that aren't installed (kde#390053)
  * Show a beautiful disabled icon for updates (kde#390076)
  * Make sure we mark as busy before clearling the list (kde#390114)
  * Add some paddings to the Review button (kde#390030)
  * Make it possible to specify a fallback appstream id (kde#390016)
  * Use the default passive notification amount (kde#388087)
  * Remove redundant action (kde#389767)
  * Fix tests, now we don't show a list from a URL
  * Only show the description for PackageKit sources (kde#389715)
  * Print a warning when a remote can't be removed
  * Fix dummy build
  * Address source by id look-up in Flatpak source
  * Fix source removal
  * Make it possible for the source id to be different from the display string
  * Fix warnings
  * Reduce duplication in flatpak sources display
  * Flatpak: don't show full url, just the hostname (kde#389714)
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Too many changes to list here
* Wed Jan 24 2018 wbauer@tmo.at
- Build with gcc7 on Leap 42.3, gcc6 no longer works because of a
  change to the default compiler flags in openSUSE:Leap:42.3:Update
  (boo#1077345)
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Too many changes to list here
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * Keep track of the kns entries status internally
  * Revert "Make sure m_isFetching is initialized when we use it"
  * Make sure m_isFetching is initialized when we use it
  * Make it possible to navigate screenshots from the overlay (kde#387402)
  * Hide reviews page when opening the review dialog (kde#386902)
  * Revert "Improve error message when review dialog contents are wrong"
  * Improve error message when review dialog contents are wrong (kde#387261)
  * Usually applications won't be compulsory for a desktop
  * Don't show packages tightly coupled to other desktops by default
  * Readability
  * PK: Use the stream to store the information rather than the transaction (kde#386992)
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * Flatpak: Make sure we don't degrade resources' state
  * If it's busy, try again in a second
  * Group updater refreshes
  * StandardUpdater: Only refresh when it's going to make a difference
  * Narrow down the scope of a variable
  * Make it possible for updaters to show notifications at any time
  * Remove unused code
  * Remove hidden styling from the delegate's comment (kde#387221)
  * No need to explicitly notify
  * Make sure we remove the Transaction before it's destroyed
  * Revert "Install related ref instead attempting to upgrade it"
  * Install related ref instead attempting to upgrade it
  * Link to a url that still exists
  * Don't fetch updates while the updater is working
  * Remove weirdly long timer to display notifications (kde#381812)
  * Simplify notifier logic
  * Don't crash if we get into a weird state (kde#385637)
  * Remove unneeded declaration
  * Make sure we never search on an invalid KNS backend
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * Don't refresh invalid backends (kde#386045)
  * Remove unused class
  * Don't delete resources whenever asked to clear the view
  * Extend the resetModel until the model is ready to be fetched again
  * Make sure we set the page size
  * Unneeded dependency in the library
  * Fix warning
  * Remove unused code
  * --warning: don't capture unused variable
  * Properly listen to ODRS replies
  * Assert on ODRS reviews fetched
  * Don't leak QNetworkAccessManager instances
  * Recover the right delegate background color
  * Improve global updates progress reporting
  * Improve progress reporting in some PackageKit updates
  * Show errors from refreshing (kde#386244)
  * Include the progress of transactions (kde#384038)
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * Include the progress of transactions (kde#384038)
  * Fix adding remote sources
  * list items should be lighter than normal background
  * Use QQC2.Popup instead of Kirigami.OverlaySheet for screenshots (kde#385115)
  * Don't open a null application from the progress view (update transaction)
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * Fix under Qt 5.10
  * Fix tests
  * Remove our isCompact concept and use Kirigami's
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * Use the right update icon when there's no updates
  * When the delegate is compact, don't show the longDescription at all
  * Fix featured filtering
  * Fix listing several sources in an application
  * Fix warnings
  * Optimize adding resources to the model (kde#383743)
  * make for better debug output
  * Don't go through categories more than necessary
  * Properly traverse a hash with iterators
  * Use flatpak_installation_list_installed_refs for listing installed flatpaks
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Too many changes to list here
* Mon Aug 28 2017 fabian@ritter-vogt.de
- Adjust License tag
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * auto generate desktop file for url handling
  * Revert "auto generate desktop file for url handling"
  * auto generate desktop file for url handling
  * Remove the navigationEnabled concept (kde#383294)
  * Fix license, comply with our naming scheme
  * Don't disable the updates action when there are no updates (kde#383294)
  * Some elements aren't reporting a big preview
  * Fallback to the package icon if there isn't a stock icon as well
  * Prevent memory leak
  * Make sure we don't crash when opening flatpakrepo files
  * Make it possible to prevent some resources from being Reviewed
  * Don't show the version if there's none on the ApplicationPage (kde#383036)
  * Make sure we don't render HTML on the Discover page header
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * Fix launching of resources for PackageKit and Flatpak
  * Make the flatpak backend more flexible to issues
  * KNS: Don't connect the stream until the search is in place
  * Improve logic for fetching installed
  * Don't continue fetching when looking for installed resources
  * Stop keeping track of the remaining time (kde#381979)
  * Don't search on KNS when in a category the backend doesn't belong to
  * Slightly cleaner code
  * Make sure the osName isn't "quoted"
  * Allow opening links in the update changelog (kde#381768)
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * Simplify KNSBackend fetch logic (kde#380138)
  * Ignore updates for which we didn't get latest commit
  * Improvements in installation or updates for flatpak backend
  * Flatpak backend: display a popup with error when update or installation fails
  * Avoid starting update transactions twice
  * Remove unused code
  * Make sure changelogs are displayed properly (kde#381248)
  * Fix crash when using Discover during updates (kde#370906)
* Mon Jun 26 2017 fabian@ritter-vogt.de
- Switch to more generic appstream-provider and PackageKit requires
* Sun Jun 25 2017 fabian@ritter-vogt.de
- Add packagekit runtime requirement (boo#1045483)
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * Don't compare a bool to an enum
  * Fix warning
  * Also show a header when doing a global search
  * Fix typos on warnings
  * Agilize search
  * Don't read a file to put it in a temporary file again
  * Fix test
  * Fix typo
  * Populate the actionsMenu right in the SourcesPage
  * Split qml and image qrc files
  * Improve hiding of scrolling controls in the UpdatesPage (kde#380993)
  * Better integrate smaller ApplicationDelegate
  * Don't mark used as unused
  * Fix snap backend build
  * Hopefully fix build in build.ko
  * Include missing margins in the UpdatesPage header controls (kde#380992)
  * Improve apt-config integration in pknotifier
  * Integrate apt setting for periodicity in the notifier (kde#337752)
  * Remove unneeded fwd declaration
  * Centralize reload actions into a generic one that will call the backends
  * Readability
  * Also check the provider like we do in the knshandler
  * Remove unused declaration
  * Make the PackageKit backend more resistant to crashes in PackageKit (kde#376538)
  * Include a header for the settings page for better consistency
  * Don't leak QNAM factories
  * Make sure the status is initialized before using it
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * fix typo
  * Qt 5.7 is needed, make it explicit when searching for Qt
  * Change look of the close description button
  * Rename the generic snap library to DiscoverSnapClient (kde#380356)
  * Don't elide the name, always elide the category label (kde#378351)
  * Improve how we initialize json objects
  * Make the tasks page a global overlay rather than just over the pages (kde#378566)
  * Remove unused file
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * Share odrs reviews instance between flatpak and packagekit
  * fix compile
  * Fix duplicate Discover entry on the Application Menu (kde#379784)
  * Update required KF5 and Kirigami dependencies
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Too many changes to list here
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * Don't make the size of the icon match the size of the text (kde#378570)
  * Make sure categories are populated
  * Make sure QSharedPointer is included
  * Prefer override
  * Remove unneeded include
  * Fix tests
  * Fix license on the appdata file
  * Fix crash
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * Simplify the ReviewDelegate
  * Fix initialization of the ApplicationPage
  * Adapt to API changes in Kirigami 2.0
  * Use correct reference to the review model
  * Minor improvements to review delegate
  * Define variable
  * Make sure we don't call cleaned up streams (kde#376162)
  * Fix enabling/disabling sources (kde#377327)
  * Account for requestComments sometimes returning a nullptr (kde#377314)
  * Fix source removal
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * Fix how we deal with margins in the ApplicationDelegate
  * Don't stretch icons
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * Make sure we don't show warnings unless it's absolutely necessary
  * Make sure the Remove button doesn't overlap the text
  * Improve local packages display on local packages
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * Don't show the version if there's no version to show
  * Don't sort resources if the delivery is sorted
  * KNS: Improve how we react to error messages
  * Use the right name for the method
  * Also show passive errors on the console
  * Simplify code
  * Also expose YaST repository configuration if present
  * Fix arguments when running .desktop files with runservice
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * Add missing overrides
  * Make sure we don't always search to kns
  * Only notify changes when they actually change
  * Don't emit null resources
  * Don't show unexisting local packages as if local
  * Fix the SettingsPage
  * libdiscover: Remove superfluous semicolon
  * Lambda not needed anymore
  * Fix signal type, don't emit as a reference
  * Restore discover-exporter
  * Gain control over the applications shown on the main browsing page
  * Include an IconName on the notifyrc file
  * Properly process Discover positional arguments
  * associate with deb and rpm to expose local file install capability
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * See https://www.kde.org/announcements/plasma-5.8.5-5.8.95-changelog.php#discover
- Remove patches, now upstream:
  * 0001-Fix-arguments-when-running-.desktop-files-with-runse.patch
  * 0002-Also-expose-YaST-repository-configuration-if-present.patch
- Update BuildRequires:
  * Uses kirigami2 now
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
- Add patches for openSUSE integration:
  * 0001-Fix-arguments-when-running-.desktop-files-with-runse.patch
  * 0002-Also-expose-YaST-repository-configuration-if-present.patch
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
- Remove upstream patches:
  * 0001-Make-screenshots-visible-when-only-one.patch
* Wed Nov  2 2016 alarrosa@suse.com
- Added 0001-Make-screenshots-visible-when-only-one.patch which fixes
  an issue by which discover didn't show application screenshots when
  there was only one screenshot (kde#371724)
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
- Removed patches (now upstream):
    0001-Fix-build-with-older-Qt.patch
    0003-Drop-usage-of-templates-from-LinkButton.patch
    0004-Remove-unused-component.patch
    0002-Don-t-artificially-require-QtQuick-5.7.patch
* Mon Sep 26 2016 fabian@ritter-vogt.de
- Bump kirigami(-devel) requirement to 1.1.0 (kde#369323)
- Drop libqt5-qtquickcontrols2 requirement (fixed upstream)
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
- Added patches:
    0001-Fix-build-with-older-Qt.patch
    0002-Don-t-artificially-require-QtQuick-5.7.patch
    0003-Drop-usage-of-templates-from-LinkButton.patch
    0004-Remove-unused-component.patch
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
- Drop upstreamed fix_for_gcc4.diff
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Thu Mar 10 2016 tittiatcoke@gmail.com
- Recommend the lang package when the languages are packaged
  (boo#970470)
* Fri Feb  5 2016 tittiatcoke@gmail.com
- KDE Software Manager based on AppStream data (appdata)
  * Initial version 5.5.4
